Skip to contents

Computes the orthogonal Procrustes distance between subspaces spanned by U and V using singular values of U'V.

Usage

procrustes_distance(U, V)

Arguments

U, V

Basis matrices for the two subspaces.

Value

Nonnegative scalar distance.

See also

subspace_principal_angles() for computing angles between subspaces

Other subspace analysis: subspace_principal_angles(), whitened_matrix(), whitened_svd()

Examples

# \donttest{
set.seed(1)
U <- matrix(rnorm(50), nrow = 10)
V <- matrix(rnorm(50), nrow = 10)
d <- procrustes_distance(U, V)
# }